pub struct StructField {Show 13 fields
pub rust_name: Member,
pub js_name: String,
pub struct_name: Ident,
pub readonly: bool,
pub ty: Type,
pub getter: Ident,
pub setter: Ident,
pub comments: Vec<String>,
pub generate_typescript: bool,
pub generate_jsdoc: bool,
pub getter_with_clone: Option<Span>,
pub is_parent: bool,
pub wasm_bindgen: Path,
}Expand description
The field of a struct
Fields
rust_name: MemberThe name of the field in Rust code
js_name: StringThe name of the field in JS code
struct_name: IdentThe name of the struct this field is part of
readonly: boolWhether this value is read-only to JS
ty: TypeThe type of this field
getter: IdentThe name of the getter shim for this field
setter: IdentThe name of the setter shim for this field
comments: Vec<String>The doc comments on this field, if any
generate_typescript: boolWhether to generate a typescript definition for this field
generate_jsdoc: boolWhether to generate jsdoc documentation for this field
getter_with_clone: Option<Span>The span of the #[wasm_bindgen(getter_with_clone)] attribute applied
to this field, if any.
If this is Some, the auto-generated getter for this field must clone
the field instead of copying it.
is_parent: boolWhether this field is the macro-injected parent field — i.e. has
type wasm_bindgen::Parent<T> — for an extends relationship.
Parent fields are not exposed to JS as getters/setters; they exist
only for Rust-side upcast projection.
wasm_bindgen: PathPath to wasm_bindgen