pub struct JsNamespace(pub Vec<String>);Expand description
A list of identifiers representing the namespace prefix of an imported function or constant, or for exported types.
The list is guaranteed to be non-empty and not start with a non-value JS keyword (except for “default”, which is allowed as a special case).
Tuple Fields
0: Vec<String>Trait Implementations
Sourceimpl Clone for JsNamespace
impl Clone for JsNamespace
Sourcefn clone(&self) -> JsNamespace
fn clone(&self) -> JsNamespace
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for JsNamespace
impl RefUnwindSafe for JsNamespace
impl Send for JsNamespace
impl Sync for JsNamespace
impl Unpin for JsNamespace
impl UnsafeUnpin for JsNamespace
impl UnwindSafe for JsNamespace