pub struct ParseOutput {
pub program: Program,
pub tokens: TokenStream,
pub main: Option<Ident>,
}Expand description
Parsed upstream macro-support AST plus Rust tokens preserved by the parser.
The parser emits these tokens for user Rust items that must remain in the expanded output while the AST carries wasm-bindgen metadata for generated glue.
Fields
program: Programtokens: TokenStreammain: Option<Ident>Auto Trait Implementations
impl !Send for ParseOutput
impl !Sync for ParseOutput
impl Freeze for ParseOutput
impl RefUnwindSafe for ParseOutput
impl Unpin for ParseOutput
impl UnsafeUnpin for ParseOutput
impl UnwindSafe for ParseOutput